@@ -8,7 +8,7 @@
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 3 of the License, or
  *   (at your option) any later version.
  *
  *   This program is distributed in the hope that it will be useful,
@@ -17,8 +17,7 @@
  *   GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software Foundation,
- *   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -29,6 +28,7 @@
 #include <limits.h>
 #include <stdio.h>
 #include <string.h>
+#include <strings.h>
 #include <ctype.h>
 #include <errno.h>
 
@@ -207,7 +207,7 @@ account_t *find_account_by_envelope_from(list_t *acc_list, const char *from)
     {
 	acc_list = acc_list->next;
 	acc_from = ((account_t *)(acc_list->data))->from;
-	if (acc_from && strcmp(from, acc_from) == 0)
+	if (acc_from && strcasecmp(from, acc_from) == 0)
 	{
 	    a = acc_list->data;
 	    break;
